@@ -54,6 +54,21 @@
 #define mysql_sqlstate(svsock) (NULL)
 #endif
 
+/*
+ * This is the version of libmysql that starts to support
+ * MySQL Fabric.
+*/
+#define LIBMYSQL_FABRIC_VERSION 60200
+
+#if LIBMYSQL_VERSION_ID >= LIBMYSQL_FABRIC_VERSION
+#define FABRIC_SUPPORT 1
+#else
+#define FABRIC_SUPPORT 0
+#endif
+
+#if MYSQL_VERSION_ID < WARNING_COUNT_VERSION
+#define mysql_warning_count(svsock) 0
+#endif
 
 #if MYSQL_VERSION_ID < WARNING_COUNT_VERSION
 #define mysql_warning_count(svsock) 0
@@ -172,6 +187,7 @@ struct imp_dbh_st {
 #endif
 #if defined(sv_utf8_decode) && MYSQL_VERSION_ID >=SERVER_PREPARE_VERSION
     bool enable_utf8;
+    bool enable_utf8mb4;
 #endif
     struct {
 	    unsigned int auto_reconnects_ok;
@@ -213,6 +229,7 @@ typedef struct imp_sth_phb_st {
 typedef struct imp_sth_fbh_st {
     unsigned long  length;
     bool           is_null;
+    bool           error;
     char           *data;
     int            charsetnr;
     double         ddata;
